@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2007, Jason Kivlighn (jkivlighn@gmail.com)
@@ -61,11 +60,11 @@
 
 #define ZLIBBUFSIZ 8192
 
-static gchar		  *ontologies_dir;
+static gchar              *ontologies_dir;
 static gboolean            initialized;
 
 static void
-load_ontology_file_from_path (const gchar	 *ontology_file)
+load_ontology_file_from_path (const gchar        *ontology_file)
 {
 	TrackerTurtleReader *reader;
 	GError              *error = NULL;
@@ -280,9 +279,9 @@ load_ontology_file_from_path (const gchar	 *ontology_file)
 }
 
 static void
-load_ontology_file (const gchar	      *filename)
+load_ontology_file (const gchar               *filename)
 {
-	gchar		*ontology_file;
+	gchar           *ontology_file;
 
 	ontology_file = g_build_filename (ontologies_dir, filename, NULL);
 	load_ontology_file_from_path (ontology_file);
@@ -290,9 +289,9 @@ load_ontology_file (const gchar	      *filename)
 }
 
 static void
-import_ontology_file (const gchar	      *filename)
+import_ontology_file (const gchar             *filename)
 {
-	gchar		*ontology_file;
+	gchar           *ontology_file;
 	GError          *error = NULL;
 
 	ontology_file = g_build_filename (ontologies_dir, filename, NULL);
@@ -312,9 +311,9 @@ class_add_super_classes_from_db (TrackerDBInterface *iface, TrackerClass *class)
 	TrackerDBCursor *cursor;
 
 	stmt = tracker_db_interface_create_statement (iface,
-						      "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:subClassOf\") "
-						      "FROM \"rdfs:Class_rdfs:subClassOf\" "
-						      "WHERE ID = (SELECT ID FROM \"rdfs:Resource\" WHERE Uri = ?)");
+	                                              "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:subClassOf\") "
+	                                              "FROM \"rdfs:Class_rdfs:subClassOf\" "
+	                                              "WHERE ID = (SELECT ID FROM \"rdfs:Resource\" WHERE Uri = ?)");
 	tracker_db_statement_bind_text (stmt, 0, tracker_class_get_uri (class));
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
@@ -340,9 +339,9 @@ property_add_super_properties_from_db (TrackerDBInterface *iface, TrackerPropert
 	TrackerDBCursor *cursor;
 
 	stmt = tracker_db_interface_create_statement (iface,
-						      "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:subPropertyOf\") "
-						      "FROM \"rdf:Property_rdfs:subPropertyOf\" "
-						      "WHERE ID = (SELECT ID FROM \"rdfs:Resource\" WHERE Uri = ?)");
+	                                              "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:subPropertyOf\") "
+	                                              "FROM \"rdf:Property_rdfs:subPropertyOf\" "
+	                                              "WHERE ID = (SELECT ID FROM \"rdfs:Resource\" WHERE Uri = ?)");
 	tracker_db_statement_bind_text (stmt, 0, tracker_property_get_uri (property));
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
@@ -369,9 +368,9 @@ db_get_static_data (TrackerDBInterface *iface)
 	TrackerDBResultSet *result_set;
 
 	stmt = tracker_db_interface_create_statement (iface,
-						      "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"tracker:Namespace\".ID), "
-						      "\"tracker:prefix\" "
-						      "FROM \"tracker:Namespace\"");
+	                                              "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"tracker:Namespace\".ID), "
+	                                              "\"tracker:prefix\" "
+	                                              "FROM \"tracker:Namespace\"");
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
 
@@ -397,8 +396,8 @@ db_get_static_data (TrackerDBInterface *iface)
 	}
 
 	stmt = tracker_db_interface_create_statement (iface,
-						      "SELECT \"rdfs:Class\".ID, (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:Class\".ID) "
-						      "FROM \"rdfs:Class\" ORDER BY ID");
+	                                              "SELECT \"rdfs:Class\".ID, (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:Class\".ID) "
+	                                              "FROM \"rdfs:Class\" ORDER BY ID");
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
 
@@ -438,17 +437,17 @@ db_get_static_data (TrackerDBInterface *iface)
 	}
 
 	stmt = tracker_db_interface_create_statement (iface,
-						      "SELECT \"rdf:Property\".ID, (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdf:Property\".ID), "
-						      "(SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:domain\"), "
-						      "(SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:range\"), "
-						      "\"nrl:maxCardinality\", "
-						      "\"tracker:indexed\", "
-						      "\"tracker:fulltextIndexed\", "
-						      "\"tracker:transient\", "
-						      "\"tracker:isAnnotation\", "
-						      "(SELECT 1 FROM \"rdfs:Resource_rdf:type\" WHERE ID = \"rdf:Property\".ID AND "
-						              "\"rdf:type\" = (Select ID FROM \"rdfs:Resource\" WHERE Uri = '" NRL_INVERSE_FUNCTIONAL_PROPERTY "')) "
-						      "FROM \"rdf:Property\" ORDER BY ID");
+	                                              "SELECT \"rdf:Property\".ID, (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdf:Property\".ID), "
+	                                              "(SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:domain\"), "
+	                                              "(SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:range\"), "
+	                                              "\"nrl:maxCardinality\", "
+	                                              "\"tracker:indexed\", "
+	                                              "\"tracker:fulltextIndexed\", "
+	                                              "\"tracker:transient\", "
+	                                              "\"tracker:isAnnotation\", "
+	                                              "(SELECT 1 FROM \"rdfs:Resource_rdf:type\" WHERE ID = \"rdf:Property\".ID AND "
+	                                              "\"rdf:type\" = (Select ID FROM \"rdfs:Resource\" WHERE Uri = '" NRL_INVERSE_FUNCTIONAL_PROPERTY "')) "
+	                                              "FROM \"rdf:Property\" ORDER BY ID");
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
 
@@ -520,7 +519,7 @@ db_get_static_data (TrackerDBInterface *iface)
 				annotation = FALSE;
 			}
 
-			tracker_db_cursor_get_value (cursor, 8, &value);
+			tracker_db_cursor_get_value (cursor, 9, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
 				is_inverse_functional_property = TRUE;
@@ -564,7 +563,7 @@ insert_uri_in_resource_table (TrackerDBInterface *iface, const gchar *uri, gint
 	                                              "INSERT  "
 	                                              "INTO \"rdfs:Resource\" "
 	                                              "(ID, Uri, \"tracker:added\", "
-	                                                "\"tracker:modified\", Available) "
+	                                              "\"tracker:modified\", Available) "
 	                                              "VALUES (?, ?, ?, 0, 1)");
 	tracker_db_statement_bind_int (stmt, 0, id);
 	tracker_db_statement_bind_text (stmt, 1, uri);
@@ -582,25 +581,24 @@ insert_uri_in_resource_table (TrackerDBInterface *iface, const gchar *uri, gint
 }
 
 static void
-create_decomposed_metadata_property_table (TrackerDBInterface *iface, 
-					   TrackerProperty   **property, 
-					   const gchar        *service_name,
-					   const gchar       **sql_type_for_single_value,
-					   gint               *max_id)
+create_decomposed_metadata_property_table (TrackerDBInterface *iface,
+                                           TrackerProperty    *property,
+                                           const gchar        *service_name,
+                                           const gchar       **sql_type_for_single_value)
 {
 	const char *field_name;
 	const char *sql_type;
 	gboolean    transient;
 
-	field_name = tracker_property_get_name (*property);
+	field_name = tracker_property_get_name (property);
 
 	transient = !sql_type_for_single_value;
 
 	if (!transient) {
-		transient = tracker_property_get_transient (*property);
+		transient = tracker_property_get_transient (property);
 	}
 
-	switch (tracker_property_get_data_type (*property)) {
+	switch (tracker_property_get_data_type (property)) {
 	case TRACKER_PROPERTY_TYPE_STRING:
 		sql_type = "TEXT";
 		break;
@@ -619,65 +617,60 @@ create_decomposed_metadata_property_table (TrackerDBInterface *iface,
 		break;
 	}
 
-	if (transient || tracker_property_get_multiple_values (*property)) {
+	if (transient || tracker_property_get_multiple_values (property)) {
 		/* multiple values */
-		if (tracker_property_get_indexed (*property)) {
+		if (tracker_property_get_indexed (property)) {
 			/* use different UNIQUE index for properties whose
 			 * value should be indexed to minimize index size */
 			tracker_db_interface_execute_query (iface, NULL,
-				"CREATE %sTABLE \"%s_%s\" ("
-				"ID INTEGER NOT NULL, "
-				"\"%s\" %s NOT NULL, "
-				"UNIQUE (\"%s\", ID))",
-				transient ? "TEMPORARY " : "",
-				service_name,
-				field_name,
-				field_name,
-				sql_type,
-				field_name);
+			                                    "CREATE %sTABLE \"%s_%s\" ("
+			                                    "ID INTEGER NOT NULL, "
+			                                    "\"%s\" %s NOT NULL, "
+			                                    "UNIQUE (\"%s\", ID))",
+			                                    transient ? "TEMPORARY " : "",
+			                                    service_name,
+			                                    field_name,
+			                                    field_name,
+			                                    sql_type,
+			                                    field_name);
 
 			tracker_db_interface_execute_query (iface, NULL,
-				"CREATE INDEX \"%s_%s_ID\" ON \"%s_%s\" (ID)",
-				service_name,
-				field_name,
-				service_name,
-				field_name);
+			                                    "CREATE INDEX \"%s_%s_ID\" ON \"%s_%s\" (ID)",
+			                                    service_name,
+			                                    field_name,
+			                                    service_name,
+			                                    field_name);
 		} else {
 			/* we still have to include the property value in
 			 * the unique index for proper constraints */
 			tracker_db_interface_execute_query (iface, NULL,
-				"CREATE %sTABLE \"%s_%s\" ("
-				"ID INTEGER NOT NULL, "
-				"\"%s\" %s NOT NULL, "
-				"UNIQUE (ID, \"%s\"))",
-				transient ? "TEMPORARY " : "",
-				service_name,
-				field_name,
-				field_name,
-				sql_type,
-				field_name);
+			                                    "CREATE %sTABLE \"%s_%s\" ("
+			                                    "ID INTEGER NOT NULL, "
+			                                    "\"%s\" %s NOT NULL, "
+			                                    "UNIQUE (ID, \"%s\"))",
+			                                    transient ? "TEMPORARY " : "",
+			                                    service_name,
+			                                    field_name,
+			                                    field_name,
+			                                    sql_type,
+			                                    field_name);
 		}
 	} else if (sql_type_for_single_value) {
 		*sql_type_for_single_value = sql_type;
 	}
-
-	/* insert property uri in rdfs:Resource table */
-	if (max_id && tracker_property_get_uri (*property) != NULL) {
-		insert_uri_in_resource_table (iface, tracker_property_get_uri (*property),
-		                              max_id);
-	}
 }
 
 static void
 create_decomposed_metadata_tables (TrackerDBInterface *iface,
-				   TrackerClass       *service,
-				   gint               *max_id)
+                                   TrackerClass       *service,
+                                   gint               *max_id)
 {
 	const char *service_name;
 	GString    *sql;
-	TrackerProperty	  **properties, **property;
+	TrackerProperty           **properties, *property;
 	GSList      *class_properties, *field_it;
 	gboolean    main_class;
+	guint       i, n_props;
 
 	service_name = tracker_class_get_name (service);
 	main_class = (strcmp (service_name, "rdfs:Resource") == 0);
@@ -693,26 +686,28 @@ create_decomposed_metadata_tables (TrackerDBInterface *iface,
 		g_string_append (sql, ", Uri TEXT NOT NULL, Available INTEGER NOT NULL");
 	}
 
-	properties = tracker_ontology_get_properties ();
+	properties = tracker_ontology_get_properties (&n_props);
 	class_properties = NULL;
-	for (property = properties; *property; property++) {
-		if (tracker_property_get_domain (*property) == service) {
+
+	for (i = 0; i < n_props; i++) {
+		property = properties[i];
+
+		if (tracker_property_get_domain (property) == service) {
 			const gchar *sql_type_for_single_value = NULL;
 
-			create_decomposed_metadata_property_table (iface, property, 
-								   service_name, 
-								   &sql_type_for_single_value,
-								   main_class ? NULL : max_id);
+			create_decomposed_metadata_property_table (iface, property,
+			                                           service_name,
+			                                           &sql_type_for_single_value);
 
 			if (sql_type_for_single_value) {
 				/* single value */
 
-				class_properties = g_slist_prepend (class_properties, *property);
+				class_properties = g_slist_prepend (class_properties, property);
 
-				g_string_append_printf (sql, ", \"%s\" %s", 
-							tracker_property_get_name (*property), 
-							sql_type_for_single_value);
-				if (tracker_property_get_is_inverse_functional_property (*property)) {
+				g_string_append_printf (sql, ", \"%s\" %s",
+				                        tracker_property_get_name (property),
+				                        sql_type_for_single_value);
+				if (tracker_property_get_is_inverse_functional_property (property)) {
 					g_string_append (sql, " UNIQUE");
 				}
 			}
@@ -738,11 +733,11 @@ create_decomposed_metadata_tables (TrackerDBInterface *iface,
 		    && tracker_property_get_indexed (field)) {
 			field_name = tracker_property_get_name (field);
 			tracker_db_interface_execute_query (iface, NULL,
-							    "CREATE INDEX \"%s_%s\" ON \"%s\" (\"%s\")",
-							    service_name,
-							    field_name,
-							    service_name,
-							    field_name);
+			                                    "CREATE INDEX \"%s_%s\" ON \"%s\" (\"%s\")",
+			                                    service_name,
+			                                    field_name,
+			                                    service_name,
+			                                    field_name);
 		}
 	}
 
@@ -760,26 +755,29 @@ static void
 create_decomposed_transient_metadata_tables (TrackerDBInterface *iface)
 {
 	TrackerProperty **properties;
-	TrackerProperty **property;
+	TrackerProperty *property;
+	guint i, n_props;
 
-	properties = tracker_ontology_get_properties ();
+	properties = tracker_ontology_get_properties (&n_props);
 
-	for (property = properties; *property; property++) {
-		if (tracker_property_get_transient (*property)) {
+	for (i = 0; i < n_props; i++) {
+		property = properties[i];
+
+		if (tracker_property_get_transient (property)) {
 
 			TrackerClass *domain;
 			const gchar *service_name;
 			const char *field_name;
 
-			field_name = tracker_property_get_name (*property);
+			field_name = tracker_property_get_name (property);
 
-			domain = tracker_property_get_domain (*property);
+			domain = tracker_property_get_domain (property);
 			service_name = tracker_class_get_name (domain);
 
 			/* create the TEMPORARY table */
 			create_decomposed_metadata_property_table (iface, property,
-								   service_name,
-								   NULL, NULL);
+			                                           service_name,
+			                                           NULL);
 		}
 	}
 }
@@ -796,9 +794,9 @@ create_fts_table (TrackerDBInterface *iface)
 
 gboolean
 tracker_data_manager_init (TrackerDBManagerFlags  flags,
-			   const gchar           *test_schema,
-			   gboolean              *first_time,
-			   gboolean              *need_journal)
+                           const gchar           *test_schema,
+                           gboolean              *first_time,
+                           gboolean              *need_journal)
 {
 	TrackerDBInterface *iface;
 	gboolean is_first_time_index;
@@ -826,20 +824,21 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 
 	if (is_first_time_index) {
 		TrackerClass **classes;
-		TrackerClass **cl;
+		TrackerProperty **properties;
 		gint max_id = 0;
 		GList *sorted = NULL, *l;
-		gchar *test_schema_path;
+		gchar *test_schema_path = NULL;
 		const gchar *env_path;
 		GError *error = NULL;
+		guint i, n_props, n_classes;
 
 		env_path = g_getenv ("TRACKER_DB_ONTOLOGIES_DIR");
-		
+
 		if (G_LIKELY (!env_path)) {
 			ontologies_dir = g_build_filename (SHAREDIR,
-							   "tracker",
-							   "ontologies",
-							   NULL);
+			                                   "tracker",
+			                                   "ontologies",
+			                                   NULL);
 		} else {
 			ontologies_dir = g_strdup (env_path);
 		}
@@ -863,8 +862,8 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 			while (conf_file) {
 				if (g_str_has_suffix (conf_file, ".ontology")) {
 					sorted = g_list_insert_sorted (sorted,
-								       g_strdup (conf_file), 
-								       (GCompareFunc) strcmp);
+					                               g_strdup (conf_file),
+					                               (GCompareFunc) strcmp);
 				}
 				conf_file = g_dir_read_name (ontologies);
 			}
@@ -884,13 +883,21 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 			load_ontology_file_from_path (test_schema_path);
 		}
 
-		classes = tracker_ontology_get_classes ();
+		classes = tracker_ontology_get_classes (&n_classes);
 
 		tracker_data_begin_transaction ();
 
 		/* create tables */
-		for (cl = classes; *cl; cl++) {
-			create_decomposed_metadata_tables (iface, *cl, &max_id);
+		for (i = 0; i < n_classes; i++) {
+			create_decomposed_metadata_tables (iface, classes[i], &max_id);
+		}
+
+		/* insert properties into rdfs:Resource table */
+		properties = tracker_ontology_get_properties (&n_props);
+
+		for (i = 0; i < n_props; i++) {
+			insert_uri_in_resource_table (iface, tracker_property_get_uri (properties[i]),
+			                              &max_id);
 		}
 
 		create_fts_table (iface);
@@ -947,8 +954,8 @@ tracker_data_manager_get_db_option_int64 (const gchar *option)
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
 	TrackerDBResultSet *result_set;
-	gchar		   *str;
-	gint		    value = 0;
+	gchar              *str;
+	gint                value = 0;
 
 	g_return_val_if_fail (option != NULL, 0);
 
@@ -975,11 +982,11 @@ tracker_data_manager_get_db_option_int64 (const gchar *option)
 
 void
 tracker_data_manager_set_db_option_int64 (const gchar *option,
-					  gint64       value)
+                                          gint64       value)
 {
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
-	gchar		   *str;
+	gchar              *str;
 
 	g_return_if_fail (option != NULL);
 
