@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
  * Copyright (C) 2008, Nokia
@@ -54,18 +53,18 @@
 #include "tracker-exif.h"
 
 #ifdef HAVE_LIBEXIF
-#define EXIF_NAMESPACE		"Exif"
-#define EXIF_NAMESPACE_LENGTH	4
+#define EXIF_NAMESPACE          "Exif"
+#define EXIF_NAMESPACE_LENGTH   4
 #endif /* HAVE_LIBEXIF */
 
 #ifdef HAVE_EXEMPI
-#define XMP_NAMESPACE		"http://ns.adobe.com/xap/1.0/\x00"
-#define XMP_NAMESPACE_LENGTH	29
+#define XMP_NAMESPACE           "http://ns.adobe.com/xap/1.0/\x00"
+#define XMP_NAMESPACE_LENGTH    29
 #endif /* HAVE_EXEMPI */
 
 #ifdef HAVE_LIBIPTCDATA
-#define PS3_NAMESPACE		"Photoshop 3.0\0"
-#define PS3_NAMESPACE_LENGTH	14
+#define PS3_NAMESPACE           "Photoshop 3.0\0"
+#define PS3_NAMESPACE_LENGTH    14
 #include <libiptcdata/iptc-jpeg.h>
 #endif /* HAVE_LIBIPTCDATA */
 
@@ -89,7 +88,7 @@ typedef struct {
 } MergeData;
 
 static void extract_jpeg (const gchar          *filename,
-			  TrackerSparqlBuilder *metadata);
+                          TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData data[] = {
 	{ "image/jpeg", extract_jpeg },
@@ -103,7 +102,7 @@ struct tej_error_mgr {
 
 static void
 insert_keywords (TrackerSparqlBuilder *metadata,
-		 gchar                *keywords)
+                 gchar                *keywords)
 {
 	char *saveptr, *p;
 	size_t len;
@@ -125,8 +124,16 @@ insert_keywords (TrackerSparqlBuilder *metadata,
 	for (p = strtok_r (keywords, ",; ", &saveptr);
 	     p;
 	     p = strtok_r (NULL, ",; ", &saveptr)) {
-		tracker_sparql_builder_predicate (metadata, "nie:keyword");
+		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
+
+		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_predicate (metadata, "a");
+		tracker_sparql_builder_object (metadata, "nao:Tag");
+
+		tracker_sparql_builder_predicate (metadata, "nao:prefLabel");
 		tracker_sparql_builder_object_unvalidated (metadata, p);
+
+		tracker_sparql_builder_object_blank_close (metadata);
 	}
 }
 
@@ -140,7 +147,7 @@ extract_jpeg_error_exit (j_common_ptr cinfo)
 
 static void
 extract_jpeg (const gchar          *uri,
-	      TrackerSparqlBuilder *metadata)
+              TrackerSparqlBuilder *metadata)
 {
 	struct jpeg_decompress_struct cinfo;
 	struct tej_error_mgr tejerr;
@@ -221,20 +228,18 @@ extract_jpeg (const gchar          *uri,
 #ifdef HAVE_LIBEXIF
 				if (strncmp (EXIF_NAMESPACE, str, EXIF_NAMESPACE_LENGTH) == 0) {
 					tracker_read_exif ((unsigned char*) marker->data,
-							   len,
-							   uri,
-							   &ed);
+					                   len,
+					                   uri,
+					                   &ed);
 				}
 #endif /* HAVE_LIBEXIF */
 
 #ifdef HAVE_EXEMPI
 				if (strncmp (XMP_NAMESPACE, str, XMP_NAMESPACE_LENGTH) == 0) {
-					TrackerXmpData xd = { 0 };
-
 					tracker_read_xmp (str + XMP_NAMESPACE_LENGTH,
-							  len - XMP_NAMESPACE_LENGTH,
-							  uri,
-							  &xd);
+					                  len - XMP_NAMESPACE_LENGTH,
+					                  uri,
+					                  &xd);
 				}
 #endif /* HAVE_EXEMPI */
 
@@ -248,9 +253,9 @@ extract_jpeg (const gchar          *uri,
 					offset = iptc_jpeg_ps3_find_iptc (str, len, &sublen);
 					if (offset > 0) {
 						tracker_read_iptc (str + offset,
-								   sublen,
-								   uri,
-								   &id);
+						                   sublen,
+						                   uri,
+						                   &id);
 					}
 				}
 #endif /* HAVE_LIBIPTCDATA */
@@ -289,9 +294,9 @@ extract_jpeg (const gchar          *uri,
 			g_free (ed.make);
 		}
 
-		md.title = tracker_coalesce (2, xd.title, ed.document_name);
+		md.title = tracker_coalesce (3, xd.title, xd.Title, ed.document_name, xd.PDFtitle);
 		md.orientation = tracker_coalesce (3, ed.orientation, xd.Orientation, id.image_orientation);
-		md.copyright = tracker_coalesce (3, ed.copyright, xd.rights, id.copyright_notice);
+		md.copyright = tracker_coalesce (3, ed.copyright, xd.Copyright, xd.rights, id.copyright_notice);
 		md.white_balance = tracker_coalesce (2, ed.white_balance, xd.WhiteBalance);
 		md.fnumber =  tracker_coalesce (2, ed.fnumber, xd.FNumber);
 		md.flash =  tracker_coalesce (2, ed.flash, xd.Flash);
@@ -319,6 +324,11 @@ extract_jpeg (const gchar          *uri,
 			g_free (xd.keywords);
 		}
 
+		if (xd.PDFkeywords) {
+			insert_keywords (metadata, xd.PDFkeywords);
+			g_free (xd.PDFkeywords);
+		}
+
 		if (xd.subject) {
 			insert_keywords (metadata, xd.subject);
 			g_free (xd.subject);
@@ -506,8 +516,42 @@ extract_jpeg (const gchar          *uri,
 			g_free (md.comment);
 		}
 
+		if (xd.Address || xd.Country || xd.City) {
+			tracker_sparql_builder_predicate (metadata, "mlo:location");
+	
+			tracker_sparql_builder_object_blank_open (metadata);
+			tracker_sparql_builder_predicate (metadata, "a");
+			tracker_sparql_builder_object (metadata, "mlo:GeoPoint");
+	
+			if (xd.Address) {
+				tracker_sparql_builder_predicate (metadata, "mlo:address");
+				tracker_sparql_builder_object_unvalidated (metadata, xd.Address);
+				g_free (xd.Address);
+			}
+	
+			if (xd.State) {
+				tracker_sparql_builder_predicate (metadata, "mlo:state");
+				tracker_sparql_builder_object_unvalidated (metadata, xd.State);
+				g_free (xd.State);
+			}
+	
+			if (xd.City) {
+				tracker_sparql_builder_predicate (metadata, "mlo:city");
+				tracker_sparql_builder_object_unvalidated (metadata, xd.City);
+				g_free (xd.City);
+			}
+	
+			if (xd.Country) {
+				tracker_sparql_builder_predicate (metadata, "mlo:country");
+				tracker_sparql_builder_object_unvalidated (metadata, xd.Country);
+				g_free (xd.Country);
+			}
+		
+			tracker_sparql_builder_object_blank_close (metadata);
+		}
+
 		jpeg_destroy_decompress (&cinfo);
-fail:
+	fail:
 		tracker_file_close (f, FALSE);
 	}
 
