@@ -380,9 +380,11 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 		g_free (exif_data.make);
 	}
 
-	merge_data.title = tracker_coalesce (3, tiff_data.documentname,
-	                                     xmp_data.title, xmp_data.Title,
-	                                     exif_data.document_name);
+	merge_data.title = tracker_coalesce (5, tiff_data.documentname,
+	                                     xmp_data.title, 
+	                                     xmp_data.Title,
+	                                     exif_data.document_name,
+	                                     xmp_data.PDFtitle);
 
 	merge_data.orientation = tracker_coalesce (4, tiff_data.orientation,
 	                                           exif_data.orientation,
@@ -464,6 +466,11 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 		g_free (xmp_data.keywords);
 	}
 
+	if (xmp_data.PDFkeywords) {
+		insert_keywords (metadata, uri, xmp_data.PDFkeywords);
+		g_free (xmp_data.PDFkeywords);
+	}
+
 	if (xmp_data.subject) {
 		insert_keywords (metadata, uri, xmp_data.subject);
 		g_free (xmp_data.subject);
@@ -530,6 +537,40 @@ extract_tiff (const gchar *uri, TrackerSparqlBuilder *metadata)
 		g_free (xmp_data.license);
 	}
 
+	if (xmp_data.Address || xmp_data.Country || xmp_data.City) {
+		tracker_sparql_builder_predicate (metadata, "mlo:location");
+
+		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_predicate (metadata, "a");
+		tracker_sparql_builder_object (metadata, "mlo:GeoPoint");
+
+		if (xmp_data.Address) {
+			tracker_sparql_builder_predicate (metadata, "mlo:address");
+			tracker_sparql_builder_object_unvalidated (metadata, xmp_data.Address);
+			g_free (xmp_data.Address);
+		}
+
+		if (xmp_data.State) {
+			tracker_sparql_builder_predicate (metadata, "mlo:state");
+			tracker_sparql_builder_object_unvalidated (metadata, xmp_data.State);
+			g_free (xmp_data.State);
+		}
+
+		if (xmp_data.City) {
+			tracker_sparql_builder_predicate (metadata, "mlo:city");
+			tracker_sparql_builder_object_unvalidated (metadata, xmp_data.City);
+			g_free (xmp_data.City);
+		}
+
+		if (xmp_data.Country) {
+			tracker_sparql_builder_predicate (metadata, "mlo:country");
+			tracker_sparql_builder_object_unvalidated (metadata, xmp_data.Country);
+			g_free (xmp_data.Country);
+		}
+	
+		tracker_sparql_builder_object_blank_close (metadata);
+	}
+
 	if (iptc_data.keywords) {
 		insert_keywords (metadata, uri, iptc_data.keywords);
 		g_free (iptc_data.keywords);
