@@ -2,10 +2,11 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
-#include <dbus/dbus-glib-lowlevel.h>
-#include <dbus/dbus-glib.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdio.h>
+#include <dbus/dbus-glib-lowlevel.h>
+#include <dbus/dbus-glib.h>
 #include <glib/gi18n-lib.h>
 #include <dbus/dbus.h>
 
@@ -20,9 +21,10 @@
 typedef struct _TrackerSearchToolServer TrackerSearchToolServer;
 typedef struct _TrackerSearchToolServerClass TrackerSearchToolServerClass;
 typedef struct _TrackerSearchToolServerPrivate TrackerSearchToolServerPrivate;
+#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
+#define _g_option_context_free0(var) ((var == NULL) ? NULL : (var = (g_option_context_free (var), NULL)))
 #define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
 #define _dbus_g_connection_unref0(var) ((var == NULL) ? NULL : (var = (dbus_g_connection_unref (var), NULL)))
-#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
 
 #define TYPE_TRACKER_QUERY (tracker_query_get_type ())
 #define TRACKER_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TRACKER_QUERY, TrackerQuery))
@@ -91,8 +93,18 @@ struct _DBusObjectVTable {
 
 extern GtkWindow* window;
 GtkWindow* window = NULL;
+extern char* service;
+char* service = NULL;
+extern char** terms;
+extern gint terms_length1;
+char** terms = NULL;
+gint terms_length1 = 0;
+extern gboolean print_version;
+gboolean print_version = FALSE;
 static gpointer tracker_search_tool_server_parent_class = NULL;
 
+#define ABOUT "Tracker " PACKAGE_VERSION "\n"
+#define LICENSE "This program is free software and comes without any warranty.\n" "It is licensed under version 2 or later of the General Public " "License which can be viewed at:\n" "\n" "  http://www.gnu.org/licenses/gpl.txt\n"
 GType tracker_search_tool_server_get_type (void);
 enum  {
 	TRACKER_SEARCH_TOOL_SERVER_DUMMY_PROPERTY
@@ -134,36 +146,37 @@ void _main (char** args, int args_length1);
 static void _vala_dbus_register_object (DBusConnection* connection, const char* path, void* object);
 static void _vala_dbus_unregister_object (gpointer connection, GObject* object);
 
+static const GOptionEntry options[] = {{"service", 's', 0, G_OPTION_ARG_STRING, &service, "Search from a specific service", "SERVICE"}, {"version", 'V', 0, G_OPTION_ARG_NONE, &print_version, "Print version", NULL}, {"", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &terms, "search terms", NULL}, {NULL}};
 static const DBusObjectPathVTable _tracker_search_tool_server_dbus_path_vtable = {_tracker_search_tool_server_dbus_unregister, tracker_search_tool_server_dbus_message};
 static const _DBusObjectVTable _tracker_search_tool_server_dbus_vtable = {tracker_search_tool_server_dbus_register_object};
 
 
-#line 29 "tracker-search-tool.gs"
+#line 45 "tracker-search-tool.gs"
 void tracker_search_tool_server_Show (TrackerSearchToolServer* self) {
-#line 29 "tracker-search-tool.gs"
+#line 45 "tracker-search-tool.gs"
 	g_return_if_fail (self != NULL);
-#line 30 "tracker-search-tool.gs"
+#line 46 "tracker-search-tool.gs"
 	gtk_window_present (window);
-#line 148 "tracker-search-tool.c"
+#line 161 "tracker-search-tool.c"
 }
 
 
-#line 28 "tracker-search-tool.gs"
+#line 44 "tracker-search-tool.gs"
 TrackerSearchToolServer* tracker_search_tool_server_construct (GType object_type) {
-#line 154 "tracker-search-tool.c"
+#line 167 "tracker-search-tool.c"
 	TrackerSearchToolServer * self;
-#line 28 "tracker-search-tool.gs"
+#line 44 "tracker-search-tool.gs"
 	self = (TrackerSearchToolServer*) g_object_new (object_type, NULL);
-#line 158 "tracker-search-tool.c"
+#line 171 "tracker-search-tool.c"
 	return self;
 }
 
 
-#line 28 "tracker-search-tool.gs"
+#line 44 "tracker-search-tool.gs"
 TrackerSearchToolServer* tracker_search_tool_server_new (void) {
-#line 28 "tracker-search-tool.gs"
+#line 44 "tracker-search-tool.gs"
 	return tracker_search_tool_server_construct (TYPE_TRACKER_SEARCH_TOOL_SERVER);
-#line 167 "tracker-search-tool.c"
+#line 180 "tracker-search-tool.c"
 }
 
 
@@ -325,15 +338,16 @@ static gpointer _g_object_ref0 (gpointer self) {
 
 #line 7481 "gtk+-2.0.vapi"
 static void _gtk_main_quit_gtk_object_destroy (GtkWindow* _sender, gpointer self) {
-#line 329 "tracker-search-tool.c"
+#line 342 "tracker-search-tool.c"
 	gtk_main_quit ();
 }
 
 
-#line 32 "tracker-search-tool.gs"
+#line 48 "tracker-search-tool.gs"
 void _main (char** args, int args_length1) {
-#line 336 "tracker-search-tool.c"
+#line 349 "tracker-search-tool.c"
 	GError * _inner_error_;
+	GOptionContext* option_context;
 	TrackerSearchToolServer* server;
 	GtkBuilder* builder;
 	GtkWindow* _tmp4_;
@@ -352,9 +366,58 @@ void _main (char** args, int args_length1) {
 	GObject* _tmp8_;
 	GtkContainer* detail_box;
 	_inner_error_ = NULL;
-#line 33 "tracker-search-tool.gs"
+#line 49 "tracker-search-tool.gs"
 	gtk_init (&args_length1, &args);
-#line 358 "tracker-search-tool.c"
+#line 372 "tracker-search-tool.c"
+	option_context = g_option_context_new ("tracker-search-tool");
+#line 54 "tracker-search-tool.gs"
+	g_option_context_set_help_enabled (option_context, TRUE);
+#line 55 "tracker-search-tool.gs"
+	g_option_context_add_main_entries (option_context, options, NULL);
+#line 378 "tracker-search-tool.c"
+	{
+#line 58 "tracker-search-tool.gs"
+		g_option_context_parse (option_context, &args_length1, &args, &_inner_error_);
+#line 382 "tracker-search-tool.c"
+		if (_inner_error_ != NULL) {
+			if (_inner_error_->domain == G_OPTION_ERROR) {
+				goto __catch4_g_option_error;
+			}
+			goto __finally4;
+		}
+	}
+	goto __finally4;
+	__catch4_g_option_error:
+	{
+		GError * e;
+		e = _inner_error_;
+		_inner_error_ = NULL;
+		{
+#line 62 "tracker-search-tool.gs"
+			fprintf (stdout, "%s\n", e->message);
+#line 63 "tracker-search-tool.gs"
+			fprintf (stdout, "Run '%s --help' to see a full list of available command line options.\n", args[0]);
+#line 401 "tracker-search-tool.c"
+			_g_error_free0 (e);
+			_g_option_context_free0 (option_context);
+			return;
+		}
+	}
+	__finally4:
+	if (_inner_error_ != NULL) {
+		_g_option_context_free0 (option_context);
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+		g_clear_error (&_inner_error_);
+		return;
+	}
+#line 66 "tracker-search-tool.gs"
+	if (print_version) {
+#line 67 "tracker-search-tool.gs"
+		fprintf (stdout, "\n" ABOUT "\n" LICENSE "\n");
+#line 418 "tracker-search-tool.c"
+		_g_option_context_free0 (option_context);
+		return;
+	}
 	server = tracker_search_tool_server_new ();
 	{
 		DBusGProxy* bus;
@@ -368,71 +431,73 @@ void _main (char** args, int args_length1) {
 		if (_inner_error_ != NULL) {
 			_g_object_unref0 (bus);
 			if (_inner_error_->domain == DBUS_GERROR) {
-				goto __catch3_dbus_gerror;
+				goto __catch5_dbus_gerror;
 			}
-			goto __finally3;
+			goto __finally5;
 		}
-#line 43 "tracker-search-tool.gs"
+#line 78 "tracker-search-tool.gs"
 		bus = (_tmp0_ = dbus_g_proxy_new_for_name (conn, "org.freedesktop.DBus", "/org/freedesktop/DBus", "org.freedesktop.DBus"), _g_object_unref0 (bus), _tmp0_);
-#line 378 "tracker-search-tool.c"
+#line 441 "tracker-search-tool.c"
 		_tmp1_ = _dynamic_request_name0 (bus, "org.freedesktop.Tracker1.SearchTool", (guint) 0, &_inner_error_);
 		if (_inner_error_ != NULL) {
 			_g_object_unref0 (bus);
 			_dbus_g_connection_unref0 (conn);
 			if (_inner_error_->domain == DBUS_GERROR) {
-				goto __catch3_dbus_gerror;
+				goto __catch5_dbus_gerror;
 			}
-			goto __finally3;
+			goto __finally5;
 		}
-#line 47 "tracker-search-tool.gs"
+#line 82 "tracker-search-tool.gs"
 		_result_ = _tmp1_;
-#line 49 "tracker-search-tool.gs"
+#line 84 "tracker-search-tool.gs"
 		if (_result_ == DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER) {
-#line 50 "tracker-search-tool.gs"
+#line 85 "tracker-search-tool.gs"
 			_vala_dbus_register_object (dbus_g_connection_get_connection (conn), "/org/freedesktop/Tracker1/SearchTool", (GObject*) server);
-#line 394 "tracker-search-tool.c"
+#line 457 "tracker-search-tool.c"
 		} else {
 			DBusGProxy* remote;
 			DBusGProxy* _tmp2_;
 			remote = NULL;
-#line 54 "tracker-search-tool.gs"
+#line 89 "tracker-search-tool.gs"
 			remote = (_tmp2_ = dbus_g_proxy_new_for_name (conn, "org.freedesktop.Tracker1.SearchTool", "/org/freedesktop/Tracker1/SearchTool", "org.freedesktop.Tracker1.SearchTool"), _g_object_unref0 (remote), _tmp2_);
-#line 58 "tracker-search-tool.gs"
+#line 93 "tracker-search-tool.gs"
 			_dynamic_show1 (remote, &_inner_error_);
-#line 403 "tracker-search-tool.c"
+#line 466 "tracker-search-tool.c"
 			if (_inner_error_ != NULL) {
 				_g_object_unref0 (remote);
 				_g_object_unref0 (bus);
 				_dbus_g_connection_unref0 (conn);
 				if (_inner_error_->domain == DBUS_GERROR) {
-					goto __catch3_dbus_gerror;
+					goto __catch5_dbus_gerror;
 				}
-				goto __finally3;
+				goto __finally5;
 			}
 			_g_object_unref0 (remote);
 			_g_object_unref0 (bus);
 			_dbus_g_connection_unref0 (conn);
+			_g_option_context_free0 (option_context);
 			_g_object_unref0 (server);
 			return;
 		}
 		_g_object_unref0 (bus);
 		_dbus_g_connection_unref0 (conn);
 	}
-	goto __finally3;
-	__catch3_dbus_gerror:
+	goto __finally5;
+	__catch5_dbus_gerror:
 	{
 		GError * e;
 		e = _inner_error_;
 		_inner_error_ = NULL;
 		{
-#line 61 "tracker-search-tool.gs"
-			g_warning ("tracker-search-tool.gs:61: %s", e->message);
-#line 431 "tracker-search-tool.c"
+#line 96 "tracker-search-tool.gs"
+			g_warning ("tracker-search-tool.gs:96: %s", e->message);
+#line 495 "tracker-search-tool.c"
 			_g_error_free0 (e);
 		}
 	}
-	__finally3:
+	__finally5:
 	if (_inner_error_ != NULL) {
+		_g_option_context_free0 (option_context);
 		_g_object_unref0 (server);
 		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
 		g_clear_error (&_inner_error_);
@@ -440,32 +505,32 @@ void _main (char** args, int args_length1) {
 	}
 	builder = gtk_builder_new ();
 	{
-#line 66 "tracker-search-tool.gs"
+#line 101 "tracker-search-tool.gs"
 		gtk_builder_add_from_file (builder, SRCDIR "tst.ui", &_inner_error_);
-#line 446 "tracker-search-tool.c"
+#line 511 "tracker-search-tool.c"
 		if (_inner_error_ != NULL) {
-			goto __catch4_g_error;
-			goto __finally4;
+			goto __catch6_g_error;
+			goto __finally6;
 		}
 	}
-	goto __finally4;
-	__catch4_g_error:
+	goto __finally6;
+	__catch6_g_error:
 	{
 		GError * e;
 		e = _inner_error_;
 		_inner_error_ = NULL;
 		{
 			{
-#line 71 "tracker-search-tool.gs"
+#line 106 "tracker-search-tool.gs"
 				gtk_builder_add_from_file (builder, TRACKER_UI_DIR "tst.ui", &_inner_error_);
-#line 462 "tracker-search-tool.c"
+#line 527 "tracker-search-tool.c"
 				if (_inner_error_ != NULL) {
-					goto __catch5_g_error;
-					goto __finally5;
+					goto __catch7_g_error;
+					goto __finally7;
 				}
 			}
-			goto __finally5;
-			__catch5_g_error:
+			goto __finally7;
+			__catch7_g_error:
 			{
 				GError * e;
 				e = _inner_error_;
@@ -473,38 +538,40 @@ void _main (char** args, int args_length1) {
 				{
 					GtkMessageDialog* msg;
 					msg = g_object_ref_sink ((GtkMessageDialog*) gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, N_ ("Failed to load UI\n%s"), e->message));
-#line 78 "tracker-search-tool.gs"
+#line 113 "tracker-search-tool.gs"
 					gtk_dialog_run ((GtkDialog*) msg);
-#line 79 "tracker-search-tool.gs"
+#line 114 "tracker-search-tool.gs"
 					gtk_main_quit ();
-#line 481 "tracker-search-tool.c"
+#line 546 "tracker-search-tool.c"
 					_g_error_free0 (e);
 					_g_object_unref0 (msg);
 				}
 			}
-			__finally5:
+			__finally7:
 			if (_inner_error_ != NULL) {
 				_g_error_free0 (e);
+				_g_option_context_free0 (option_context);
 				_g_object_unref0 (server);
 				_g_object_unref0 (builder);
-				goto __finally4;
+				goto __finally6;
 			}
 			_g_error_free0 (e);
 		}
 	}
-	__finally4:
+	__finally6:
 	if (_inner_error_ != NULL) {
+		_g_option_context_free0 (option_context);
 		_g_object_unref0 (server);
 		_g_object_unref0 (builder);
 		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
 		g_clear_error (&_inner_error_);
 		return;
 	}
-#line 82 "tracker-search-tool.gs"
+#line 117 "tracker-search-tool.gs"
 	window = (_tmp4_ = _g_object_ref0 ((_tmp3_ = gtk_builder_get_object (builder, "window"), GTK_IS_WINDOW (_tmp3_) ? ((GtkWindow*) _tmp3_) : NULL)), _g_object_unref0 (window), _tmp4_);
-#line 83 "tracker-search-tool.gs"
+#line 118 "tracker-search-tool.gs"
 	g_signal_connect ((GtkObject*) window, "destroy", (GCallback) _gtk_main_quit_gtk_object_destroy, NULL);
-#line 508 "tracker-search-tool.c"
+#line 575 "tracker-search-tool.c"
 	query = tracker_query_new ();
 	entry = g_object_ref_sink (tracker_search_entry_new ());
 	grid = g_object_ref_sink (tracker_result_grid_new ());
@@ -514,31 +581,32 @@ void _main (char** args, int args_length1) {
 	grid_box = _g_object_ref0 ((_tmp6_ = gtk_builder_get_object (builder, "GridBox"), GTK_IS_CONTAINER (_tmp6_) ? ((GtkContainer*) _tmp6_) : NULL));
 	category_box = _g_object_ref0 ((_tmp7_ = gtk_builder_get_object (builder, "CategoryBox"), GTK_IS_CONTAINER (_tmp7_) ? ((GtkContainer*) _tmp7_) : NULL));
 	detail_box = _g_object_ref0 ((_tmp8_ = gtk_builder_get_object (builder, "DetailBox"), GTK_IS_CONTAINER (_tmp8_) ? ((GtkContainer*) _tmp8_) : NULL));
-#line 100 "tracker-search-tool.gs"
+#line 135 "tracker-search-tool.gs"
 	tracker_query_Connect (query);
-#line 101 "tracker-search-tool.gs"
+#line 136 "tracker-search-tool.gs"
 	tracker_search_entry_set_Query (entry, query);
-#line 102 "tracker-search-tool.gs"
+#line 137 "tracker-search-tool.gs"
 	gtk_container_add (entry_box, (GtkWidget*) entry);
-#line 104 "tracker-search-tool.gs"
+#line 139 "tracker-search-tool.gs"
 	tracker_result_grid_set_Query (grid, query);
-#line 105 "tracker-search-tool.gs"
+#line 140 "tracker-search-tool.gs"
 	gtk_container_add (grid_box, (GtkWidget*) grid);
-#line 107 "tracker-search-tool.gs"
+#line 142 "tracker-search-tool.gs"
 	tracker_category_view_set_Query (categories, query);
-#line 108 "tracker-search-tool.gs"
+#line 143 "tracker-search-tool.gs"
 	gtk_container_add (category_box, (GtkWidget*) categories);
-#line 110 "tracker-search-tool.gs"
+#line 145 "tracker-search-tool.gs"
 	tracker_metadata_tile_set_ResultGrid (tile, grid);
-#line 111 "tracker-search-tool.gs"
+#line 146 "tracker-search-tool.gs"
 	tracker_metadata_tile_set_Query (tile, query);
-#line 112 "tracker-search-tool.gs"
+#line 147 "tracker-search-tool.gs"
 	gtk_container_add (detail_box, (GtkWidget*) tile);
-#line 114 "tracker-search-tool.gs"
+#line 149 "tracker-search-tool.gs"
 	gtk_widget_show_all ((GtkWidget*) window);
-#line 116 "tracker-search-tool.gs"
+#line 151 "tracker-search-tool.gs"
 	gtk_main ();
-#line 542 "tracker-search-tool.c"
+#line 609 "tracker-search-tool.c"
+	_g_option_context_free0 (option_context);
 	_g_object_unref0 (server);
 	_g_object_unref0 (builder);
 	_g_object_unref0 (query);
@@ -553,15 +621,15 @@ void _main (char** args, int args_length1) {
 }
 
 
-#line 32 "tracker-search-tool.gs"
+#line 48 "tracker-search-tool.gs"
 int main (int argc, char ** argv) {
-#line 32 "tracker-search-tool.gs"
+#line 48 "tracker-search-tool.gs"
 	g_type_init ();
-#line 32 "tracker-search-tool.gs"
+#line 48 "tracker-search-tool.gs"
 	_main (argv, argc);
-#line 32 "tracker-search-tool.gs"
+#line 48 "tracker-search-tool.gs"
 	return 0;
-#line 565 "tracker-search-tool.c"
+#line 633 "tracker-search-tool.c"
 }
 
 
